#aionewsapi

Asyncio client for interacting with newsapi.org

Installation instructions:

```bash
pip install aionewsapi
```

Usage:
```python

from aionewsapi import NewsAPI

client = NewsAPI()

```

Note
---------
aionewsapi is not affiliated or endorsed by any of the web services it interacts with.